#[non_exhaustive]pub enum DcConvention {
PaperPure,
Matpower,
}Expand description
Electrical convention used for DC branch coefficients.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PaperPure
Use b = 1/x and ignore transformer taps and phase shifts.
Matpower
Use b = 1/(x tau) and include phase shift injections, matching
MATPOWER makeBdc.
Implementations
Sourceimpl DcConvention
impl DcConvention
Sourcepub fn branch_susceptance(self, reactance: f64, effective_tap: f64) -> f64
pub fn branch_susceptance(self, reactance: f64, effective_tap: f64) -> f64
Compute a branch susceptance from reactance and effective tap.
Sourcepub fn includes_phase_shifts(self) -> bool
pub fn includes_phase_shifts(self) -> bool
Whether phase shifts contribute to the nodal injection vector.