pub struct SensitivityOptions {
pub convention: DcConvention,
pub solver: SensitivitySolver,
pub drop_tolerance: f64,
pub cg_tolerance: f64,
pub cg_max_iterations: usize,
pub auto_dense_threshold: usize,
}Expand description
Options for PTDF/LODF builders that expose solver choice and output pruning.
Fields
convention: DcConventionDC branch susceptance convention.
solver: SensitivitySolverSolver selection policy.
drop_tolerance: f64Entries with absolute value at or below this value are omitted from the returned sparse matrices. LODF diagonal entries are structural and kept.
cg_tolerance: f64Relative residual tolerance for the iterative solver.
cg_max_iterations: usizeMaximum conjugate gradient iterations per right hand side.
auto_dense_threshold: usizeReduced dimension above which SensitivitySolver::Auto selects the
iterative path.
Implementations
Sourceimpl SensitivityOptions
impl SensitivityOptions
Sourcepub fn selected_solver_for_reduced_dimension(
&self,
reduced_dimension: usize,
) -> SensitivitySolver
pub fn selected_solver_for_reduced_dimension( &self, reduced_dimension: usize, ) -> SensitivitySolver
Return the concrete solver selected for a reduced grounded dimension.